==> apache-camel-3.19.0-src.zip: apache-camel-3.19.0/components/camel-kamelet/src/test/java/org/apache/camel/component/kamelet/TemplatedRouteKameletTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.kamelet;

import org.apache.camel.RoutesBuilder;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

public class TemplatedRouteKameletTest extends CamelTestSupport {

    @Test
    public void testKamelet() throws Exception {
        getMockEndpoint("mock:out").expectedBodiesReceived("test-Hello");

        template.sendBody("direct:start", "Hello");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RoutesBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                routeTemplate("echo")
                        .templateParameter("prefix")
                        .from("kamelet:source")
                        .setBody().simple("{{prefix}}-${body}");

                routeTemplate("myTemplate")
                        .templateParameter("uri")
                        .templateParameter("in")
                        .templateParameter("out")
                        .from("{{in}}")
                        .to("{{uri}}")
                        .to("{{out}}");

                templatedRoute("myTemplate")
                        .parameter("in", "direct:start")
                        .parameter("uri", "kamelet:echo/test?prefix=test")
                        .parameter("out", "mock:out");
            }
        };
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-kamelet/src/test/java/org/apache/camel/component/kamelet/TemplatedRouteKameletTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.kamelet;

import org.apache.camel.RoutesBuilder;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

public class TemplatedRouteKameletTest extends CamelTestSupport {

    @Test
    public void testKamelet() throws Exception {
        getMockEndpoint("mock:out").expectedBodiesReceived("test-Hello");

        template.sendBody("direct:start", "Hello");

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected RoutesBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                routeTemplate("echo")
                        .templateParameter("prefix")
                        .from("kamelet:source")
                        .setBody().simple("{{prefix}}-${body}");

                routeTemplate("myTemplate")
                        .templateParameter("uri")
                        .templateParameter("in")
                        .templateParameter("out")
                        .from("{{in}}")
                        .to("{{uri}}")
                        .to("{{out}}");

                templatedRoute("myTemplate")
                        .parameter("in", "direct:start")
                        .parameter("uri", "kamelet:echo/test?prefix=test")
                        .parameter("out", "mock:out");
            }
        };
    }
}
